@@ -58,8 +58,13 @@ impl<'a> Enum<'a> {
                 let maybe_ret = || -> pyo3::PyResult<Self> {
                     #struct_derive
                 }();
-                if maybe_ret.is_ok() {
-                    return maybe_ret
+
+                match maybe_ret {
+                    ok @ Ok(_) => return ok,
+                    Err(inner) => {
+                        let py = pyo3::PyNativeType::py(obj);
+                        err_reasons.push_str(&format!("{}\n", inner.instance(py).str().unwrap()));
+                    }
                 }
             );
 
@@ -74,10 +79,14 @@ impl<'a> Enum<'a> {
         } else {
             error_names
         };
+        let ty_name = self.enum_ident.to_string();
         quote!(
+            let mut err_reasons = String::new();
             #(#var_extracts)*
-            let type_name = obj.get_type().name()?;
-            let err_msg = format!("'{}' object cannot be converted to '{}'", type_name, #error_names);
+            let err_msg = format!("failed to extract enum {} ('{}')\n{}",
+                #ty_name,
+                #error_names,
+                &err_reasons);
             Err(pyo3::exceptions::PyTypeError::new_err(err_msg))
         )
     }
@@ -186,7 +195,7 @@ impl<'a> Container<'a> {
     /// Build derivation body for a struct.
     fn build(&self) -> TokenStream {
         match &self.ty {
-            ContainerType::StructNewtype(ident) => self.build_newtype_struct(Some(&ident)),
+            ContainerType::StructNewtype(ident) => self.build_newtype_struct(Some(ident)),
             ContainerType::TupleNewtype => self.build_newtype_struct(None),
             ContainerType::Tuple(len) => self.build_tuple_struct(*len),
             ContainerType::Struct(tups) => self.build_struct(tups),
@@ -196,11 +205,35 @@ impl<'a> Container<'a> {
     fn build_newtype_struct(&self, field_ident: Option<&Ident>) -> TokenStream {
         let self_ty = &self.path;
         if let Some(ident) = field_ident {
+            let error_msg = format!(
+                "failed to extract field {}.{}",
+                quote!(#self_ty),
+                quote!(#ident)
+            );
             quote!(
-                Ok(#self_ty{#ident: obj.extract()?})
+                Ok(#self_ty{#ident: obj.extract().map_err(|inner| {
+                    let py = pyo3::PyNativeType::py(obj);
+                    let new_err = pyo3::exceptions::PyTypeError::new_err(#error_msg);
+                    new_err.set_cause(py, Some(inner));
+                    new_err
+                })?})
             )
         } else {
-            quote!(Ok(#self_ty(obj.extract()?)))
+            let error_msg = if self.is_enum_variant {
+                let variant_name = &self.path.segments.last().unwrap();
+                format!("- variant {} ({})", quote!(#variant_name), &self.err_name)
+            } else {
+                format!("failed to extract inner field of {}", quote!(#self_ty))
+            };
+            quote!(
+                Ok(#self_ty(obj.extract().map_err(|inner| {
+                    let py = pyo3::PyNativeType::py(obj);
+                    let err_msg = format!("{}: {}",
+                        #error_msg,
+                        inner.instance(py).str().unwrap());
+                    pyo3::exceptions::PyTypeError::new_err(err_msg)
+                })?))
+            )
         }
     }
 
@@ -208,7 +241,14 @@ impl<'a> Container<'a> {
         let self_ty = &self.path;
         let mut fields: Punctuated<TokenStream, syn::Token![,]> = Punctuated::new();
         for i in 0..len {
-            fields.push(quote!(s.get_item(#i).extract()?));
+            let error_msg = format!("failed to extract field {}.{}", quote!(#self_ty), i);
+            fields.push(quote!(
+                s.get_item(#i).extract().map_err(|inner| {
+                let py = pyo3::PyNativeType::py(obj);
+                let new_err = pyo3::exceptions::PyTypeError::new_err(#error_msg);
+                new_err.set_cause(py, Some(inner));
+                new_err
+                })?));
         }
         let msg = if self.is_enum_variant {
             quote!(format!(
@@ -238,11 +278,25 @@ impl<'a> Container<'a> {
                 FieldGetter::GetItem(Some(key)) => quote!(get_item(#key)),
                 FieldGetter::GetItem(None) => quote!(get_item(stringify!(#ident))),
             };
-
+            let conversion_error_msg =
+                format!("failed to extract field {}.{}", quote!(#self_ty), ident);
             let get_field = quote!(obj.#getter?);
             let extractor = match &attrs.from_py_with {
-                None => quote!(#get_field.extract()?),
-                Some(FromPyWithAttribute(expr_path)) => quote! (#expr_path(#get_field)?),
+                None => quote!(
+                    #get_field.extract().map_err(|inner| {
+                    let py = pyo3::PyNativeType::py(obj);
+                    let new_err = pyo3::exceptions::PyTypeError::new_err(#conversion_error_msg);
+                    new_err.set_cause(py, Some(inner));
+                    new_err
+                })?),
+                Some(FromPyWithAttribute(expr_path)) => quote! (
+                    #expr_path(#get_field).map_err(|inner| {
+                        let py = pyo3::PyNativeType::py(obj);
+                        let new_err = pyo3::exceptions::PyTypeError::new_err(#conversion_error_msg);
+                        new_err.set_cause(py, Some(inner));
+                        new_err
+                    })?
+                ),
             };
 
             fields.push(quote!(#ident: #extractor));
